Package: aedseo
Title: Automated and Early Detection of Seasonal Epidemic Onset and
        Burden Levels
Version: 1.1.0
Authors@R: c(
    person("Sofia", "Myrup Otero", , "smot@ssi.dk", role = c("aut"),
            comment = c(ORCID = "0009-0006-4953-614X")),
    person("Kasper", "Schou Telkamp", ,"kasper.telkamp@gmail.com", role = c("aut"),
            comment = c(ORCID = "0009-0001-5126-0190")),
    person("Lasse Engbo", "Christiansen", , "lsec@ssi.dk", role = c("aut", "cre"),
            comment = c(ORCID = "0000-0001-5019-1931")),
    person("Rasmus Skytte", "Randl\u00F8v", , "rske@ssi.dk", role = c("rev"),
            comment = c(ORCID = "0000-0002-5860-3838")),
    person("Statens Serum Institut, SSI", role = c("cph", "fnd"))
    )
Description: A powerful tool for automating the early detection of seasonal epidemic
             onsets in time series data. It offers the ability to estimate growth rates
             across consecutive time intervals, calculate the sum of cases (SoC) within
             those intervals, and estimate seasonal onsets within user defined seasons.
             With use of a disease-specific threshold it also offers the possibility to
             estimate seasonal onset of epidemics.
             Additionally it offers the ability to estimate burden levels for seasons
             based on historical data. It is aimed towards epidemiologists,
             public health professionals, and researchers seeking to identify and respond
             to seasonal epidemics in a timely fashion.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
URL: https://github.com/ssi-dk/aedseo, https://ssi-dk.github.io/aedseo/
BugReports: https://github.com/ssi-dk/aedseo/issues
Depends: R (>= 4.2.0)
Suggests: grid, ISOweek, kableExtra, knitr, mem, rmarkdown, testthat
        (>= 3.0.0), withr
Config/testthat/edition: 3
Imports: base, checkmate, dplyr, ggplot2, lifecycle, lubridate, plyr,
        purrr, pracma, rlang, scales, stats, stringr, tibble, tidyr
Config/Needs/website: rmarkdown
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-01-23 13:51:57 UTC; b246418
Author: Sofia Myrup Otero [aut] (ORCID:
    <https://orcid.org/0009-0006-4953-614X>),
  Kasper Schou Telkamp [aut] (ORCID:
    <https://orcid.org/0009-0001-5126-0190>),
  Lasse Engbo Christiansen [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-5019-1931>),
  Rasmus Skytte Randløv [rev] (ORCID:
    <https://orcid.org/0000-0002-5860-3838>),
  Statens Serum Institut, SSI [cph, fnd]
Maintainer: Lasse Engbo Christiansen <lsec@ssi.dk>
Repository: CRAN
Date/Publication: 2026-01-23 14:50:01 UTC
Built: R 4.6.0; ; 2026-04-26 15:59:22 UTC; unix
