# Generated by roxygen2: do not edit by hand

S3method(autoplot,tsd)
S3method(autoplot,tsd_growth_warning)
S3method(autoplot,tsd_onset)
S3method(autoplot,tsd_onset_and_burden)
S3method(plot,tsd)
S3method(plot,tsd_growth_warning)
S3method(plot,tsd_onset)
S3method(plot,tsd_onset_and_burden)
S3method(predict,tsd_onset)
S3method(summary,tsd_burden_levels)
S3method(summary,tsd_onset)
export(autoplot)
export(combined_seasonal_output)
export(consecutive_growth_warnings)
export(epi_calendar)
export(estimate_disease_threshold)
export(fit_growth_rate)
export(fit_percentiles)
export(generate_seasonal_data)
export(historical_summary)
export(seasonal_burden_levels)
export(seasonal_onset)
export(to_time_series)
importFrom(ggplot2,autoplot)
importFrom(graphics,plot)
importFrom(lifecycle,deprecated)
importFrom(rlang,.data)
importFrom(tibble,tibble)
